# coding: utf-8

"""
    PCM Vulnerabilities API

     Module containing a class for interacting with the PCM Vulnerabilities API.   # noqa: E501
"""

from setuptools import setup, find_packages  # noqa: H301

NAME="pcm_vulnerabilities_api"
VERSION='0.3.0'
REQUIRES=[
    'boto3>=1.18.1',
    'jinja2>=2.11.3',
    'numpy>=1.16.5, <1.20',
    'pandas==1.2.4',
    'openpyxl==3.0.6',
    'requests>=2.25.1',
    'Deprecated>=1.2.12'
]

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="PCM Vulnerabilities API",
    author="Pearson Service Insights",
    author_email="TOIOServiceWorkflowAutomation@grp.pearson.com",
    url="https://gitlab.com/pearson-io-swa/integrations",
    keywords=["Pearson", "PCM", "PSI", "Vulnerabilities"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
     Module containing a class for interacting with the PCM Vulnerabilities API.   # noqa: E501
    """
)
